# PaymentType

The type of the payment. 

## Enum

* `EXTERNAL` (value: `'External'`)

* `ELECTRONIC` (value: `'Electronic'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


